import type { Router } from 'vue-router'
import { useUserStore } from '@/store/modules/user'

/** 路由白名单 */
const whitePathList = ['/login']

export function createRouterGuards(router: Router) {
  router.beforeEach((to) => {
    window.$loadingBar.start()

    const userStore = useUserStore()

    if (userStore.isLogin && to.fullPath === '/login') {
      return false
    }

    // 白名单直接跳过
    if (whitePathList.includes(to.path)) {
      return true
    }

    if (!userStore.isLogin && !whitePathList.includes(to.fullPath)) {
      return { path: '/login', query: { redirect: encodeURIComponent(to.fullPath) } }
    }

    return true
  })

  router.afterEach((to) => {
    document.title = to.meta.hiddenTitle ? '' : (to.meta.title as string) || document.title

    window.$loadingBar.finish()
  })

  router.onError((error) => {
    console.log(error, '--路由错误--')
  })
}
