import { defineStore } from 'pinia'
import { ss } from '@/utils/storage'
import { TOKEN, IS_LOGIN, USER_INFO } from '@/utils/storage-key'
import type { UserState, UserInfo } from '../types/user'

function getDefaultUserInfo(): UserInfo {
  return {
    account: '',
    userAccount: '',
    userId: null,
    userName: '用户',
    createdTime: '',
    avatar: '',
  }
}

export const useUserStore = defineStore('user-store', {
  state: (): UserState => ({
    isLogin: ss.get(IS_LOGIN),
    token: ss.get(TOKEN) || '',
    userInfo: ss.get(USER_INFO) || getDefaultUserInfo(),
  }),
  actions: {
    async logout() {
      this.isLogin = false
      this.token = ''
      this.userInfo = getDefaultUserInfo()

      ss.remove(IS_LOGIN)
      ss.remove(TOKEN)
      ss.remove(USER_INFO)
    },
    updateIsLogin(status: boolean) {
      this.isLogin = status
      ss.set(IS_LOGIN, status)
    },
    updateToken(token: string) {
      this.token = token
      ss.set(TOKEN, token)
    },
    updateUserInfo(userInfo: UserInfo) {
      this.userInfo = userInfo
      ss.set(USER_INFO, userInfo)
    },
  },
})
